/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EjbJarDeployableFactory.java 3602 2008-07-04 15:42:01Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.metadata.ejbjar;


import java.util.Set;

import org.ow2.easybeans.deployment.metadata.ejbjar.configurator.EjbJarDeployableMetadataConfigurator;
import org.ow2.easybeans.deployment.metadata.ejbjar.helper.MetadataSpecificMerge;
import org.ow2.easybeans.deployment.metadata.ejbjar.xml.EasyBeansDD;
import org.ow2.easybeans.deployment.metadata.ejbjar.xml.EasyBeansDeploymentDesc;
import org.ow2.util.ee.deploy.api.deployable.EJB3Deployable;
import org.ow2.util.ee.metadata.ejbjar.impl.specific.ISpecificEjbJarDeployableFactory;
import org.ow2.util.ee.metadata.ejbjar.impl.specific.ISpecificEjbJarDeployableMetadataConfigurator;
import org.ow2.util.ee.metadata.ejbjar.impl.xml.EJB3DeploymentDescException;

/**
 * @author Gael Lalire
 */
public class EjbJarDeployableFactory implements ISpecificEjbJarDeployableFactory<EJB3Deployable> {

    private EjbJarArchiveMetadata ezbSpecificWarDeployableMetadata;

    private EasyBeansDD easyBeansDD;

    public EjbJarDeployableFactory() {
        this.ezbSpecificWarDeployableMetadata = new EjbJarArchiveMetadata();
    }

    public ISpecificEjbJarDeployableMetadataConfigurator<EJB3Deployable> beforeScan(final EJB3Deployable deployable, final Set<String> classNameSet) {
        this.ezbSpecificWarDeployableMetadata.setDeployable(deployable);
        // read easybeans.xml
        // Get Specific DD
        try {
            this.easyBeansDD = EasyBeansDeploymentDesc.getEasyBeansDD(deployable.getArchive());
        } catch (EJB3DeploymentDescException e) {
            this.easyBeansDD = null;
            // TODO gaellalire : exception ?
        }

        EjbJarDeployableMetadataConfigurator ezbSpecificWarDeployableMetadataConfigurator = new EjbJarDeployableMetadataConfigurator(
                this.ezbSpecificWarDeployableMetadata);
        return ezbSpecificWarDeployableMetadataConfigurator;
    }

    public void afterScan() {
        // create shortcut
        for (EjbJarClassMetadata ezbSpecificWarClassMetadata : this.ezbSpecificWarDeployableMetadata
                .getEjbJarClassMetadataCollection()) {
            for (EjbJarMethodMetadata ejbJarMethodMetadata : ezbSpecificWarClassMetadata.getSpecificMethodMetadataCollection()) {
                if (ejbJarMethodMetadata.isAroundInvoke()) {
                    ezbSpecificWarClassMetadata.addAroundInvokeMethodMetadata(ejbJarMethodMetadata);
                }
                if (ejbJarMethodMetadata.isPostActivate()) {
                    ezbSpecificWarClassMetadata.addPostActivateMethodMetadata(ejbJarMethodMetadata);
                }
                if (ejbJarMethodMetadata.isPostConstruct()) {
                    ezbSpecificWarClassMetadata.addPostConstructMethodMetadata(ejbJarMethodMetadata);
                }
                if (ejbJarMethodMetadata.isPreDestroy()) {
                    ezbSpecificWarClassMetadata.addPreDestroyMethodMetadata(ejbJarMethodMetadata);
                }
                if (ejbJarMethodMetadata.isPrePassivate()) {
                    ezbSpecificWarClassMetadata.addPrePassivateMethodMetadata(ejbJarMethodMetadata);
                }
            }
        }

        // Merge specific DD
        this.ezbSpecificWarDeployableMetadata.setEasyBeansDD(this.easyBeansDD);
        MetadataSpecificMerge.merge(this.ezbSpecificWarDeployableMetadata);

        // merge easybeans.xml with metadata
    }

    public EjbJarArchiveMetadata getEzbSpecificWarDeployableMetadata() {
        return this.ezbSpecificWarDeployableMetadata;
    }


}
