/**
 * EasyBeans
 * Copyright (C) 2006-2007 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: EjbJarMethodMetadata.java 3356 2008-05-30 09:49:21Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.metadata.ejbjar;

import org.ow2.util.ee.deploy.api.deployable.EJB3Deployable;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.ee.metadata.ejbjar.impl.specific.SpecificEjbJarMethodMetadata;
import org.ow2.util.scan.api.metadata.structures.JMethod;

/**
 * This class represents the annotation metadata of a method.
 * @author Florent Benoit
 */
public class EjbJarMethodMetadata extends
        SpecificEjbJarMethodMetadata<EJB3Deployable, EjbJarClassMetadata, EjbJarMethodMetadata, EjbJarFieldMetadata> {

    /**
     * This method is a method from a super class ?<br>
     */
    private boolean inherited = false;

    /**
     * Original parent metadata (if method is inherited).
     */
    private EjbJarClassMetadata originalClassMetadata = null;

    /**
     * Class metadata.
     */
    private EjbJarClassMetadata classMetadata = null;

    public EjbJarMethodMetadata(final IEjbJarMethodMetadata<EJB3Deployable> warMethodMetadata,
            final EjbJarClassMetadata classMetadata) {
        super(warMethodMetadata, classMetadata);
        // TODO Auto-generated constructor stub
    }

    public EjbJarMethodMetadata(final JMethod removeMethod, final EjbJarClassMetadata bean) {
        super(new org.ow2.util.ee.metadata.ejbjar.impl.EjbJarMethodMetadata<EJB3Deployable>(removeMethod, bean.getStandard()),
                bean);
        // do not do : bean.getStandard().addMethodMetadata(getStandard());
        // because the standard should not be modified
    }

    /**
     * @return true if this method is inherited from a super class
     */
    public boolean isInherited() {
        return this.inherited;
    }

    /**
     * Sets the inheritance of this method.
     * @param inherited true if method is from a super class
     * @param originalClassMetadata the metadata of the original class (not
     *        inherited)
     */
    public void setInherited(final boolean inherited, final EjbJarClassMetadata originalClassMetadata) {
        this.inherited = inherited;
        this.originalClassMetadata = originalClassMetadata;
    }

    /**
     * @return original parent metadata (class) if inherited.
     */
    public EjbJarClassMetadata getOriginalClassMetadata() {
        return this.originalClassMetadata;
    }

    /**
     * @param classMetadata the new class metadata
     */
    public void setSpecificClassMetadata(final EjbJarClassMetadata classMetadata) {
        this.classMetadata = classMetadata;
    }

    @Override
    public void setClassMetadata(final IEjbJarClassMetadata<EJB3Deployable> classMetadata) {
        throw new IllegalStateException("use setSpecificClassMetadata");
    }

    @Override
    public IEjbJarClassMetadata<EJB3Deployable> getClassMetadata() {
        if (this.classMetadata == null) {
            return super.getClassMetadata();
        }
        return this.classMetadata.getStandard();
    }

    @Override
    public EjbJarClassMetadata getSpecificClassMetadata() {
        if (this.classMetadata == null) {
            return super.getSpecificClassMetadata();
        }
        return this.classMetadata;
    }

}
