/**
 * OW2 Util
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * --------------------------------------------------------------------------
 * $Id: EjbJarClassMetadataConfigurator.java 3602 2008-07-04 15:42:01Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.metadata.ejbjar.configurator;

import java.util.Set;

import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarArchiveMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;
import org.ow2.util.ee.deploy.api.deployable.EJB3Deployable;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarClassMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarFieldMetadata;
import org.ow2.util.ee.metadata.ejbjar.api.IEjbJarMethodMetadata;
import org.ow2.util.pool.impl.visitor.PoolVisitor;
import org.ow2.util.scan.api.configurator.BasicConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificClassConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificFieldConfigurator;
import org.ow2.util.scan.api.configurator.metadata.specific.ISpecificMethodConfigurator;

/**
 * @author Gael Lalire
 */
public class EjbJarClassMetadataConfigurator extends BasicConfigurator
        implements
        ISpecificClassConfigurator<IEjbJarClassMetadata<EJB3Deployable>, IEjbJarMethodMetadata<EJB3Deployable>, IEjbJarFieldMetadata<EJB3Deployable>> {

    private EjbJarArchiveMetadata warDeployableMetadata;

    private EjbJarClassMetadata ezbSpecificWarClassMetadata;

    public EjbJarClassMetadataConfigurator(final IEjbJarClassMetadata<EJB3Deployable> warClassMetadata,
            final EjbJarArchiveMetadata warDeployableMetadata) {
        this.warDeployableMetadata = warDeployableMetadata;
        this.ezbSpecificWarClassMetadata = new EjbJarClassMetadata(warClassMetadata);
        registerAnnotationVisitor();
    }

    public ISpecificFieldConfigurator createSpecificFieldConfigurator(final IEjbJarFieldMetadata<EJB3Deployable> fieldMetadata) {
        return new EjbJarFieldMetadataConfigurator(fieldMetadata, this.ezbSpecificWarClassMetadata);
    }

    public ISpecificMethodConfigurator createSpecificMethodConfigurator(
            final IEjbJarMethodMetadata<EJB3Deployable> methodMetadata) {
        return new EjbJarMethodMetadataConfigurator(methodMetadata, this.ezbSpecificWarClassMetadata);
    }

    /**
     * register annotation visitor.
     */
    protected void registerAnnotationVisitor() {
        // Add @Pool specific annotation
        getAnnotationVisitors().put(PoolVisitor.TYPE, new PoolVisitor(this.ezbSpecificWarClassMetadata));

    }

    /**
     * @param referencedClasses you may fill this set with class referenced in current metadata
     */
    @Override
    public void configurationComplete(final Set<String> referencedClasses) {
        this.ezbSpecificWarClassMetadata.setSpecificDeployableMetadata(this.warDeployableMetadata);
        this.warDeployableMetadata.addEjbJarClassMetadata(this.ezbSpecificWarClassMetadata);
        super.configurationComplete(referencedClasses);
    }

}
