/**
 * EasyBeans
 * Copyright (C) 2008 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: TestMetadata.java 3389 2008-06-03 12:31:56Z gaellalire $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.deployment.test;

import java.util.Arrays;

import org.ow2.easybeans.deployment.annotations.exceptions.ResolverException;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarArchiveMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarClassMetadata;
import org.ow2.easybeans.deployment.metadata.ejbjar.EjbJarDeployableFactory;
import org.ow2.util.archive.impl.MemoryArchive;
import org.ow2.util.ee.deploy.api.deployable.EJB3Deployable;
import org.ow2.util.ee.deploy.api.deployable.metadata.DeployableMetadataException;
import org.ow2.util.ee.deploy.impl.helper.DeployableHelper;
import org.ow2.util.ee.deploy.impl.helper.DeployableHelperException;
import org.ow2.util.ee.metadata.ejbjar.impl.EjbJarDeployableMetadataFactory;
import org.ow2.util.pool.api.IPoolConfiguration;
import org.ow2.util.scan.api.ScanException;
import org.testng.Assert;
import org.testng.annotations.BeforeClass;
import org.testng.annotations.Test;

/**
 * TestMetadata.
 * @author Gael Lalire
 */
public class TestMetadata {

    /**
     * Archive metadata.
     */
    private EjbJarArchiveMetadata ejbJarAnnotationMetadata;

    /**
     * Create metadata.
     * @throws ScanException if scan issue
     * @throws DeployableHelperException if deployable helper issue
     * @throws DeployableMetadataException if metadata issue
     */
    @BeforeClass
    public void init() throws ScanException, DeployableMetadataException, DeployableHelperException, ResolverException {
        MemoryArchive memoryArchive = new MemoryArchive();
        memoryArchive.addClassResource(getClass().getClassLoader(), Arrays.asList(MyEjb.class.getName()));

        EjbJarDeployableMetadataFactory<EJB3Deployable> metadataFactory = new EjbJarDeployableMetadataFactory<EJB3Deployable>();
        EjbJarDeployableFactory deployableFactory = new EjbJarDeployableFactory();
        metadataFactory.createDeployableMetadata((EJB3Deployable) DeployableHelper.getDeployable(memoryArchive), null, Arrays
                .asList(deployableFactory));
        this.ejbJarAnnotationMetadata = deployableFactory.getEzbSpecificWarDeployableMetadata();

        // ResolverHelper.resolve(this.ejbJarAnnotationMetadata);
    }

    /**
     * Test the pool annotation (ezb specific).
     */
    @Test
    public void testPool() {
        EjbJarClassMetadata classMetadata = this.ejbJarAnnotationMetadata.getEjbJarClassMetadata(MyEjb.class.getName().replace(
                '.', '/'));
        Assert.assertTrue(classMetadata.isStateful());
        IPoolConfiguration poolConfiguration = classMetadata.getPoolConfiguration();
        Assert.assertNotNull(poolConfiguration);
        Assert.assertEquals(poolConfiguration.getMax(), MyEjb.MAX);
    }

}
